<?php
/**
 * Plugin Messages (addon for plugin Adm_redacteurs)
 * Version  : 1.1 (2017/10/23)
 * Compatibility : Guppy v5.0+ et Adm_redacteurs v6.8+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require_once ADMR_HELPERS_PATH.'/plugin_menu_helper.php';

class Plugin_menu_for_messages_helper extends Plugin_menu_helper
{
    /**
	 * Définit et retourne les items du menu qui est affiché dans le bandeau en haut de la page coté public
     * 
	 * @access public
	 * @param string Nom du document
	 * @param array Tableau contenant les traduction de langue
	 * @param array Tableau contenant les options de configuration
     * @param array Tableau contenant les paramètres des droits du rédacteur
     * @param array Paramètres optionnels
	 * @return array
	 */
	public static function set_public_items($doc_name, $lang, $config, $writer_rights = array(), $params = array())
	{
        return array(
            parent :: add_item_for_go_dashboard($doc_name, $lang),
            parent :: add_item(array( // Gestion des messages reçus
                    'is_allowed' => $writer_rights[$doc_name.'_manage'],
                    'title' => $lang['manage_'.$doc_name.'_receveid'],
                    'class' => 'manage_docs '.$doc_name,
                    'controller' => 'manage_'.$doc_name,
                    'query' => 'sort=mode_desc', // paramètres passés dans l'uri autre que le controller
                    'pattern_to_search_in_uri' => array('method' => 'strict', 'string' => 'addons/'.$doc_name.'/manage_'.$doc_name),
                    'addon_dir_path' => 'addons/'.$doc_name.'/', // Chemin du répertoire de l'addon
                 )            
            ),
            parent :: add_item(array( // Gestion des messages envoyés
                    'is_allowed' => $writer_rights[$doc_name.'_manage'],
                    'title' => $lang['manage_'.$doc_name.'_sent'],
                    'class' => 'manage_docs '.$doc_name,
                    'controller' => 'manage_'.$doc_name.'_sent',
                    'pattern_to_search_in_uri' => array('method' => 'strict', 'string' => 'addons/'.$doc_name.'/manage_'.$doc_name.'_sent'),
                    'addon_dir_path' => 'addons/'.$doc_name.'/', // Chemin du répertoire de l'addon
                 )            
            ),
            parent :: add_item_for_addon_add_doc($doc_name, $lang, $writer_rights),
            parent :: add_item_for_addon_search_docs($doc_name, $lang),
            parent :: add_item_for_disconnect($doc_name, $lang) // Déconnexion
        );           
    }

	// --------------------------------------------------------------------

    /**
	 * Définit et retourne les items du menu qui est affiché dans le bandeau en haut de la page coté admin
     * 
	 * @access public
	 * @param string Nom du document
	 * @param array Tableau contenant les traduction de langue
	 * @param array Tableau contenant les options de configuration
     * @param array Tableau contenant les paramètres des droits du rédacteur
     * @param array Paramètres optionnels
	 * @return array
	 */
	public static function set_admin_items($doc_name, $lang, $config, $writer_rights = array(), $params = array())
    {
        return array(
            parent :: add_item_for_go_dashboard($doc_name, $lang),
            parent :: add_item(array(
                    'is_allowed' => $writer_rights[$doc_name.'_manage'],
                    'title' => $lang['manage_'.$doc_name.'_receveid'],
                    'class' => 'manage_docs '.$doc_name,
                    'controller' => 'manage_'.$doc_name,
                    'query' => 'sort=mode_desc', // paramètres passés dans l'uri autre que le controller
                    'pattern_to_search_in_uri' => array('method' => 'strict', 'string' => 'addons/'.$doc_name.'/manage_'.$doc_name),
                    'addon_dir_path' => 'addons/'.$doc_name.'/', // Chemin du répertoire de l'addon
                 )            
            ),
            parent :: add_item(array(
                    'is_allowed' => $writer_rights[$doc_name.'_manage'],
                    'title' => $lang['manage_'.$doc_name.'_sent'],
                    'class' => 'manage_docs '.$doc_name,
                    'controller' => 'manage_'.$doc_name.'_sent',
                    'pattern_to_search_in_uri' => array('method' => 'strict', 'string' => 'addons/'.$doc_name.'/manage_'.$doc_name.'_sent'),
                    'addon_dir_path' => 'addons/'.$doc_name.'/', // Chemin du répertoire de l'addon
                 )            
            ),
            parent :: add_item_for_addon_add_doc($doc_name, $lang, $writer_rights),
            parent :: add_item_for_addon_search_docs($doc_name, $lang),
        );           
    }

	// --------------------------------------------------------------------

} // End of class